Stan Math Library: stan/math/prim/scal/fun Directory Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

fun Directory Reference

## Files
file | abs.hpp [code]
file | as_bool.hpp [code]
file | bessel_first_kind.hpp [code]
file | bessel_second_kind.hpp [code]
file | binary_log_loss.hpp [code]
file | binomial_coefficient_log.hpp [code]
file | constants.hpp [code]
file | corr_constrain.hpp [code]
file | corr_free.hpp [code]
file | digamma.hpp [code]
file | divide.hpp [code]
file | exp2.hpp [code]
file | F32.hpp [code]
file | falling_factorial.hpp [code]
file | fdim.hpp [code]
file | fill.hpp [code]
file | gamma_p.hpp [code]
file | gamma_q.hpp [code]
file | grad_2F1.hpp [code]
file | grad_F32.hpp [code]
file | grad_inc_beta.hpp [code]
file | grad_reg_inc_beta.hpp [code]
file | grad_reg_inc_gamma.hpp [code]
file | ibeta.hpp [code]
file | identity_constrain.hpp [code]
file | identity_free.hpp [code]
file | if_else.hpp [code]
file | inc_beta.hpp [code]
file | inc_beta_dda.hpp [code]
file | inc_beta_ddb.hpp [code]
file | inc_beta_ddz.hpp [code]
file | int_step.hpp [code]
file | inv.hpp [code]
file | inv_cloglog.hpp [code]
file | inv_logit.hpp [code]
file | inv_Phi.hpp [code]
file | inv_sqrt.hpp [code]
file | inv_square.hpp [code]
file | inverse_softmax.hpp [code]
file | is_inf.hpp [code]
file | is_nan.hpp [code]
file | is_uninitialized.hpp [code]
file | lb_constrain.hpp [code]
file | lb_free.hpp [code]
file | lbeta.hpp [code]
file | lgamma.hpp [code]
file | lmgamma.hpp [code]
file | log1m.hpp [code]
file | log1m_exp.hpp [code]
file | log1m_inv_logit.hpp [code]
file | log1p.hpp [code]
file | log1p_exp.hpp [code]
file | log2.hpp [code]
file | log_diff_exp.hpp [code]
file | log_falling_factorial.hpp [code]
file | log_inv_logit.hpp [code]
file | log_mix.hpp [code]
file | log_rising_factorial.hpp [code]
file | log_sum_exp.hpp [code]
file | logical_and.hpp [code]
file | logical_eq.hpp [code]
file | logical_gt.hpp [code]
file | logical_gte.hpp [code]
file | logical_lt.hpp [code]
file | logical_lte.hpp [code]
file | logical_negation.hpp [code]
file | logical_neq.hpp [code]
file | logical_or.hpp [code]
file | logit.hpp [code]
file | lub_constrain.hpp [code]
file | lub_free.hpp [code]
file | modified_bessel_first_kind.hpp [code]
file | modified_bessel_second_kind.hpp [code]
file | modulus.hpp [code]
file | multiply_log.hpp [code]
file | owens_t.hpp [code]
file | Phi.hpp [code]
file | Phi_approx.hpp [code]
file | positive_constrain.hpp [code]
file | positive_free.hpp [code]
file | primitive_value.hpp [code]
file | prob_constrain.hpp [code]
file | prob_free.hpp [code]
file | promote_scalar.hpp [code]
file | promote_scalar_type.hpp [code]
file | rising_factorial.hpp [code]
file | sign.hpp [code]
file | square.hpp [code]
file | step.hpp [code]
file | trigamma.hpp [code]
file | ub_constrain.hpp [code]
file | ub_free.hpp [code]
file | value_of.hpp [code]
file | value_of_rec.hpp [code]

[ Stan Home Page ] © 2011–2016, Stan Development Team.